==> ejc-settle-api-3.0.0-20240902.074024-102-sources.jar: com/ejianc/business/settle/bean/SettlementCenterOutputDetailVO.java <==
package com.ejianc.business.settle.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 结算中心卷册统计产值详情
 * 
 * @author generator
 * 
 */
public class SettlementCenterOutputDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织id
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private String dcDrwgrpInfoName; // 卷册名称
    private String settlementCenterMajorName; // 结算中心专业名称
    private Long settlementCenterMajor; // 结算中心专业
    private String dcDrwgrpInfoCode; // 卷册编码
    private String drwgrpVsn; // 卷册版本
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码
    private Long pid; // settlement_center_dc_drwgrp_info主键
    private Long userId; // 人员id
    private String userName; // 用户名称
    private String userCode; // 用户账号
    private BigDecimal statisticalOutput; // 统计产值
    

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getDcDrwgrpInfoName() {
        return dcDrwgrpInfoName;
    }

    public void setDcDrwgrpInfoName(String dcDrwgrpInfoName) {
        this.dcDrwgrpInfoName = dcDrwgrpInfoName;
    }
    public String getSettlementCenterMajorName() {
        return settlementCenterMajorName;
    }

    public void setSettlementCenterMajorName(String settlementCenterMajorName) {
        this.settlementCenterMajorName = settlementCenterMajorName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSettlementCenterMajor() {
        return settlementCenterMajor;
    }
    @ReferDeserialTransfer
    public void setSettlementCenterMajor(Long settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }
    public String getDcDrwgrpInfoCode() {
        return dcDrwgrpInfoCode;
    }

    public void setDcDrwgrpInfoCode(String dcDrwgrpInfoCode) {
        this.dcDrwgrpInfoCode = dcDrwgrpInfoCode;
    }
    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getUserId() {
        return userId;
    }
    @ReferDeserialTransfer
    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public BigDecimal getStatisticalOutput() {
        return statisticalOutput;
    }

    public void setStatisticalOutput(BigDecimal statisticalOutput) {
        this.statisticalOutput = statisticalOutput;
    }
}

==> ejc-settle-api-3.0.0-20241021.060808-110-sources.jar: com/ejianc/business/settle/bean/SettlementCenterOutputDetailVO.java <==
package com.ejianc.business.settle.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 结算中心卷册统计产值详情
 * 
 * @author generator
 * 
 */
public class SettlementCenterOutputDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织id
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private String dcDrwgrpInfoName; // 卷册名称
    private String settlementCenterMajorName; // 结算中心专业名称
    private Long settlementCenterMajor; // 结算中心专业
    private String dcDrwgrpInfoCode; // 卷册编码
    private String drwgrpVsn; // 卷册版本
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码
    private Long pid; // settlement_center_dc_drwgrp_info主键
    private Long userId; // 人员id
    private String userName; // 用户名称
    private String userCode; // 用户账号
    private BigDecimal statisticalOutput; // 统计产值

    private Integer flowState;//图纸工程量状态
    private String flowStateName;//图纸工程量状态名称


    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getDcDrwgrpInfoName() {
        return dcDrwgrpInfoName;
    }

    public void setDcDrwgrpInfoName(String dcDrwgrpInfoName) {
        this.dcDrwgrpInfoName = dcDrwgrpInfoName;
    }
    public String getSettlementCenterMajorName() {
        return settlementCenterMajorName;
    }

    public void setSettlementCenterMajorName(String settlementCenterMajorName) {
        this.settlementCenterMajorName = settlementCenterMajorName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSettlementCenterMajor() {
        return settlementCenterMajor;
    }
    @ReferDeserialTransfer
    public void setSettlementCenterMajor(Long settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }
    public String getDcDrwgrpInfoCode() {
        return dcDrwgrpInfoCode;
    }

    public void setDcDrwgrpInfoCode(String dcDrwgrpInfoCode) {
        this.dcDrwgrpInfoCode = dcDrwgrpInfoCode;
    }
    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getUserId() {
        return userId;
    }
    @ReferDeserialTransfer
    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public BigDecimal getStatisticalOutput() {
        return statisticalOutput;
    }

    public void setStatisticalOutput(BigDecimal statisticalOutput) {
        this.statisticalOutput = statisticalOutput;
    }

    public Integer getFlowState() {
        return flowState;
    }

    public void setFlowState(Integer flowState) {
        this.flowState = flowState;
    }

    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }
}
